# Security Policy

Please report security vulnerabilities through GitHub's
[private vulnerability reporting](https://github.com/Niccolum/dature/security/advisories/new).

Do NOT open public issues for security vulnerabilities.
